@@ -1,7 +1,7 @@
 /* LICENSE BEGIN
     This file is part of the SixtyFPS Project -- https://sixtyfps.io
-    Copyright (c) 2020 Olivier Goffart <olivier.goffart@sixtyfps.io>
-    Copyright (c) 2020 Simon Hausmann <simon.hausmann@sixtyfps.io>
+    Copyright (c) 2021 Olivier Goffart <olivier.goffart@sixtyfps.io>
+    Copyright (c) 2021 Simon Hausmann <simon.hausmann@sixtyfps.io>
 
     SPDX-License-Identifier: GPL-3.0-only
     This file is also available under commercial licensing terms.
@@ -443,7 +443,7 @@ macro_rules! new_vref {
         // ensure that the type of the expression is correct
         let vtable = {
             use $crate::VTableMeta;
-            fn get_vt<X: $trait_>(_: &X) -> <$vtable as VTableMeta>::VTable {
+            fn get_vt<X: $trait_>(_: &mut X) -> <$vtable as VTableMeta>::VTable {
                 <$vtable as VTableMeta>::VTable::new::<X>()
             }
             get_vt($e)
@@ -530,7 +530,7 @@ impl<Base, T: ?Sized + VTableMeta> VOffset<Base, T, AllowPin> {
     /// Apply this offset to a reference to the base to obtain a `Pin<VRef<'a, T>>` with the same
     /// lifetime as the base lifetime
     #[inline]
-    pub fn apply_pin<'a>(self, base: Pin<&'a Base>) -> Pin<VRef<'a, T>> {
+    pub fn apply_pin(self, base: Pin<&Base>) -> Pin<VRef<T>> {
         let ptr = base.get_ref() as *const Base as *mut u8;
         unsafe {
             Pin::new_unchecked(VRef::from_raw(
